.. Bowtie documentation master file, created by
   sphinx-quickstart on Fri Aug 19 23:07:25 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Components
==========

Find the list of supported components here and how to use them.

Visuals
-------

Plotly
~~~~~~

.. autoclass:: bowtie.visual.Plotly
    :members:
    :undoc-members:

Table
~~~~~

.. autoclass:: bowtie.visual.Table
    :members:
    :undoc-members:

SVG
~~~

.. autoclass:: bowtie.visual.SVG
    :members:
    :undoc-members:

SmartGrid
~~~~~~~~~

.. autoclass:: bowtie.visual.SmartGrid
    :members:
    :undoc-members:

Progress
--------

.. automodule:: bowtie._progress
    :members:
    :undoc-members:

Controllers
-----------

Button
~~~~~~

.. autoclass:: bowtie.control.Button
    :members:
    :undoc-members:

Dropdown
~~~~~~~~

.. autoclass:: bowtie.control.Dropdown
    :members:
    :undoc-members:

Switch
~~~~~~

.. autoclass:: bowtie.control.Switch
    :members:
    :undoc-members:

DatePicker
~~~~~~~~~~

.. autoclass:: bowtie.control.DatePicker
    :members:
    :undoc-members:

MonthPicker
~~~~~~~~~~~

.. autoclass:: bowtie.control.MonthPicker
    :members:
    :undoc-members:

RangePicker
~~~~~~~~~~~

.. autoclass:: bowtie.control.RangePicker
    :members:
    :undoc-members:

Textbox
~~~~~~~

.. autoclass:: bowtie.control.Textbox
    :members:
    :undoc-members:

Number
~~~~~~

.. autoclass:: bowtie.control.Number
    :members:
    :undoc-members:

Slider
~~~~~~

.. autoclass:: bowtie.control.Slider
    :members:
    :undoc-members:

NoUISlider
~~~~~~~~~~

.. autoclass:: bowtie.control.Nouislider
    :members:
    :undoc-members:

Upload
~~~~~~

.. autoclass:: bowtie.control.Upload
    :members:
    :undoc-members:

HTML
----

Markdown
~~~~~~~~

.. autoclass:: bowtie.html.Markdown
    :members:
    :undoc-members:

Div
~~~

.. autoclass:: bowtie.html.Div
    :members:
    :undoc-members:

Header
~~~~~~

.. autoclass:: bowtie.html.Header
    :members:
    :undoc-members:

Link
~~~~

.. autoclass:: bowtie.html.Link
    :members:
    :undoc-members:
